/**
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 -
 - JASS: Java Advanced tranSaction Support
 -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 -
 - This module was originally developed by 
 -
 -    LSD (Distributed Systems Lab, http://lsd.ls.fi.upm.es/lsd/lsd.htm)
 -    at Universidad Politecnica de Madrid (UPM) as an ObjectWeb Consortium
 -    (http://www.objectweb.org) project.
 -
 -    This project has been partially funded by the European Commission under
 -    the IST programme of V FP grant IST-2001-37126 and by the Spanish
 -    Ministry of Science & Technology (MCyT) grants TIC2002-10376-E and
 -    TIC2001-1586-C03-02
 -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 -  The original code and portions created by LSD are 
 -  Copyright (c) 2004 LSD (UPM)  
 -  All rights reserved.
 -  
 - Redistribution and use in source and binary forms, with or without 
 - modification, are permitted provided that the following conditions are met:
 -
 - -Redistributions of source code must retain the above copyright notice, this
 - list of conditions and the following disclaimer. 
 -
 - -Redistributions in binary form must reproduce the above copyright notice, 
 - this list of conditions and the following disclaimer in the documentation 
 - and/or other materials provided with the distribution. 
 -
 - THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 - AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 - IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 - ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 - LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 - CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 - SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 - INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 - CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 - ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 - POSSIBILITY OF SUCH DAMAGE.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 -
 -  Author: Francisco Perez-Sorrosal (fpsorrosal@fi.upm.es)
 -
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
*/

package javax.activity;

import javax.activity.coordination.Action;

public interface ActivityCoordinator {

	public void addAction(
		Action action,
		java.lang.String signalSetName,
		int priority)
		throws
			SignalSetUnknownException,
			SystemException,
			java.lang.IllegalStateException;

	public void addGlobalAction(Action action, int priority)
		throws SystemException, java.lang.IllegalStateException;

	public void removeAction(Action action, java.lang.String signalSetName)
		throws
			ActionNotFoundException, SystemException, java.lang.IllegalStateException;

	public void removeGlobalAction(Action action)
		throws
			ActionNotFoundException, SystemException, java.lang.IllegalStateException;

	public int getNumberRegisteredActions(java.lang.String signalSetName)
		throws SignalSetUnknownException, SystemException;

	public void setCompletionSignalSetName(java.lang.String signalSetName)
		throws
			SignalSetUnknownException,
			SystemException,
			java.lang.IllegalStateException;

	public java.lang.String getCompletionSignalSetName() throws SystemException;

	public ActivityCoordinator getParent() throws SystemException;

	public GlobalId getGlobalId() throws SystemException;

	public int getStatus() throws SystemException;

	public int getParentStatus() throws SystemException;

	public java.lang.String getName() throws SystemException;

	public boolean isSameActivity(ActivityCoordinator coord)
		throws SystemException;

	public Action[] getActions(java.lang.String signalSetName)
		throws SignalSetUnknownException, SystemException;

	public Outcome completeActivity(int completionStatus)
		throws
			ActivityPendingException,
			ContextPendingException,
			NotOriginatorException,
			InvalidStateException,
			ActivityNotProcessedException,
			SystemException;

	public Outcome heuristicComplete(int completionStatus)
		throws
			ActivityPendingException,
			ContextPendingException,
			InvalidStateException,
			ActivityNotProcessedException,
			SystemException;

	public Outcome processSignalSet(
		java.lang.String signalSetName,
		int completionStatus)
		throws
			SignalSetUnknownException,
			ActivityNotProcessedException,
			InvalidActivityException,
			SystemException;

	// ------------------------------------------------------------------------
    // This methods are added to extend the functionality of the AS for replication
    // ------------------------------------------------------------------------
    
    public void associateCurrentThread();
    
    public void disassociateCurrentThread();
    
    public void associateActivityManager(ActivityManager am);
    
    // ------------------------------------------------------------------------
    
}
